# Encoding: UTF-8

from compositry.tasks import Task
from compositry import state

__version__ = "0.4.0"
